@@ -7,7 +7,7 @@ This module contains a Status class for status updates to the Toolchest API.
 
 from enum import Enum
 
-class Status(Enum):
+class Status(str, Enum):
     """Status values for the Toolchest API."""
 
     INITIALIZED = "initialized"
@@ -19,3 +19,4 @@ class Status(Enum):
     READY_TO_TRANSFER_TO_CLIENT = "ready_to_transfer_to_client"
     TRANSFERRING_TO_CLIENT = "transferring_to_client"
     TRANSFERRED_TO_CLIENT = "transferred_to_client"
+    FAILED = "failed"
